<?php

/**
 * A helper class for working with ClickHouse.
 */
class CClickHouseHelper {

	/**
	 * Perform request to ClickHouse.
	 *
	 * @param string $method      HTTP method to be used to perform request
	 * @param string $endpoint    requested url
	 * @param mixed  $request     data to be sent
	 *
	 * @return string    result
	 */
	private static function request($method, $endpoint, $query) {
		$options = [
			'http' => [
				'header'  => "Content-Type: application/json; charset=UTF-8",
				'method'  => $method,
				'ignore_errors' => true // To get error messages from ClickHouse.
			]
		];

		$query .= ' FORMAT JSONCompact';
		$options['http']['content'] = $query;

		try {
			$response = file_get_contents($endpoint, false, stream_context_create($options));
		}
		catch (Exception $e) {
			error($e->getMessage());
		}

		return json_decode($response, true);
	}

	public static function values($method, $endpoint, $query = null, $columns = null, $map = null) {
		#file_put_contents('/var/log/nginx/chartlog.log', "$query\n\n", FILE_APPEND);
		$response = self::request($method, $endpoint, $query);

		$values = [];
		foreach ($response['data'] as $row) {
			$value = [];
			for($i = 0; $i < count($row); $i++)
			{
				if ($columns) {
					$column = $columns[$i];
				} else {
					$column = $response['meta'][$i]['name'];
				}

				if ($map && array_key_exists($column, $map))
				{
					$column = $map[$column];
				}

				$value[$column] = $row[$i];
			}
			$values[] = $value;
		}
		#$json = json_encode($values, true);
		#file_put_contents('/var/log/nginx/chartlog.log', "$json\n", FILE_APPEND);
		return $values;
	}

	public static function value($method, $endpoint, $query = null, $column = 'value') {
		$values = self::values($method, $endpoint, $query, [$column]);

		if ((count($values) > 0) && array_key_exists($column, $values[0])) {
			return $values[0][$column];
		}
		return null;
	}
}
